==> haskell-crypto-api-tests-0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-CjS6nkvH6Ry303omtfGikv
key: crypto-api-tests-0.3-CjS6nkvH6Ry303omtfGikv
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 47622dbdd9d6c85e4f03d3862f370533
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-CjS6nkvH6Ry303omtfGikv
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    bytestring-0.10.8.2 cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU directory-1.3.1.5
    filepath-1.4.2 test-framework-0.8.2.0-DhLbYTIlvP2DU0cHcKcIVn
    test-framework-hunit-0.3.0.2-3WEttnD9c0tEyrtYkupqrv
    test-framework-quickcheck2-0.3.0.4-5JmVoDGCwSV9ArVcMib0GX
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU=6900b771227d4e4da26f3f5981befd1d
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             test-framework-0.8.2.0-DhLbYTIlvP2DU0cHcKcIVn=d1efc953df9f0f5d7a2c271019506a2e
             test-framework-hunit-0.3.0.2-3WEttnD9c0tEyrtYkupqrv=e4869c327a31c4685956fa7527e184bd
             test-framework-quickcheck2-0.3.0.4-5JmVoDGCwSV9ArVcMib0GX=4c18e55e93e56398d9e4fab99ea79fee
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api-tests
version: 0.3
id: crypto-api-tests-0.3-H6QxO6qzW9U9p4XORkqQzS
key: crypto-api-tests-0.3-H6QxO6qzW9U9p4XORkqQzS
license: BSD-3-Clause
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: http://trac.haskell.org/crypto-api/wiki
synopsis: A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).
category: Data, Cryptography
abi: 870424378ea6a2860fd0b715f215f294
exposed: True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish
hidden-modules: Paths_crypto_api_tests
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-api-tests-0.3
hs-libraries: HScrypto-api-tests-0.3-H6QxO6qzW9U9p4XORkqQzS
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    bytestring-0.10.8.2 cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ directory-1.3.1.5
    filepath-1.4.2 test-framework-0.8.2.0-DhLbYTIlvP2DU0cHcKcIVn
    test-framework-hunit-0.3.0.2-3WEttnD9c0tEyrtYkupqrv
    test-framework-quickcheck2-0.3.0.4-5JmVoDGCwSV9ArVcMib0GX
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=ce10e49cbca1b74596de9d427ce328a8
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             test-framework-0.8.2.0-DhLbYTIlvP2DU0cHcKcIVn=d1efc953df9f0f5d7a2c271019506a2e
             test-framework-hunit-0.3.0.2-3WEttnD9c0tEyrtYkupqrv=e4869c327a31c4685956fa7527e184bd
             test-framework-quickcheck2-0.3.0.4-5JmVoDGCwSV9ArVcMib0GX=4c18e55e93e56398d9e4fab99ea79fee
haddock-interfaces: /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock
haddock-html: /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
